%define oname	getfem

%define major	4
%define libname	%mklibname %{oname} %{major}
%define devname %mklibname %{oname} -d

Name:           getfem++
Summary:        Generic and efficient C++ library for finite element methods
Version:        4.2
Release:        %mkrel 12
Url:            http://home.gna.org/getfem/
License:        LGPLv2+
Group:          Development/C++
BuildRequires:	blas-devel
BuildRequires:	boost-devel
BuildRequires:	muparser-devel
BuildRequires:	qhull-devel
BuildRequires:	lapack-devel
BuildRequires:	python-numpy-devel
BuildRequires:	python-devel
Source0:	http://download.gna.org/getfem/stable/getfem-%version.tar.gz
Patch0:		getfem-4.2-fix-str-fmt.patch
Patch1:		getfem-4.2-libqhull.patch
Patch2:		getfem-4.2-top_srcdir.patch

%description
The Getfem++ project focuses on the development of a generic and efficient
C++ library for finite element methods. The goal is to provide a library
allowing the computation of any elementary matrix (even for mixed finite
element methods) on the largest class of methods and elements, and for
arbitrary dimension (i.e. not only 2D and 3D problems).

%package -n %{devname}
Summary:	Development files and headers for %{name}
Group:		Development/C++
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{oname}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Recommends:	%{oname}-examples = %{version}-%{release}
Obsoletes:	%{name} < 4.2-7

%description -n %{devname}
This package contains the development files and headers for %{name}.

%files -n %{devname}
%{_bindir}/getfem-config
%{_includedir}/gmm/
%{_includedir}/getfem/
%{_includedir}/getfem_boost/
%{_libdir}/libgetfem.a
%{_libdir}/libgetfem.so

%package -n %{libname}
Summary:	Shared libraries for %{name}
Group:		System/Libraries

%description -n %{libname}
The Getfem++ project focuses on the development of a generic and efficient
C++ library for finite element methods. The goal is to provide a library
allowing the computation of any elementary matrix (even for mixed finite
element methods) on the largest class of methods and elements, and for
arbitrary dimension (i.e. not only 2D and 3D problems).

%files -n %{libname}
%doc README
%{_libdir}/libgetfem.so.%{major}
%{_libdir}/libgetfem.so.%{major}.*

%package -n python-getfem
Group:		Development/Python
Summary:	Python binding for %{name}

%description -n python-getfem
Python binding for %{name}.

%files -n python-getfem
%ifarch x86_64
%dir %py_platsitedir/getfem
%endif
%dir %py_puresitedir/getfem
%py_platsitedir/getfem/_getfem.so
%py_puresitedir/getfem/__init__.*
%py_puresitedir/getfem/getfem.py*

%package -n %{oname}-examples
Summary:	Examples for %{name}
Group:		Development/C++
BuildArch:	noarch
Conflicts:	%{name} < 4.2-7

%description -n %{oname}-examples
This package contains some examples for %{name}.

%files -n %{oname}-examples
%{_prefix}/getfem_toolbox/

#--------------------------------------------------------------------

%prep
%setup -qn getfem-%{version}
%autopatch -p1

%build
autoreconf -vfi
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure2_5x \
	--enable-boost \
	--enable-shared
%make

%install
%makeinstall_std

find %{buildroot} -name '*.la' -delete


%changelog
* Sun Feb 14 2016 umeabot <umeabot> 4.2-12.mga6
+ Revision: 960276
- Mageia 6 Mass Rebuild

* Mon Aug 31 2015 cjw <cjw> 4.2-11.mga6
+ Revision: 871419
- rebuild with gcc 5

* Wed Oct 15 2014 umeabot <umeabot> 4.2-10.mga5
+ Revision: 748687
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 4.2-9.mga5
+ Revision: 726318
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 4.2-8.mga5
+ Revision: 679547
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

* Sat Jun 28 2014 wally <wally> 4.2-7.mga5
+ Revision: 640846
- enable shared build
- add lib and devel pkgs
- split out some examples
- add patches to fix build

* Sat May 31 2014 pterjan <pterjan> 4.2-6.mga5
+ Revision: 628216
- Rebuild for new Python

* Sat Oct 19 2013 umeabot <umeabot> 4.2-5.mga4
+ Revision: 529452
- Mageia 4 Mass Rebuild

* Tue Jul 09 2013 fwang <fwang> 4.2-4.mga4
+ Revision: 451859
- br python
- rebuild for new boost

* Sat Jan 12 2013 umeabot <umeabot> 4.2-3.mga3
+ Revision: 351488
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 22 2012 fwang <fwang> 4.2-2.mga3
+ Revision: 333778
- bump rel
- update file list
- update file list
- build shared libs
- add more br
- fix str fmt
- new version 4.2

* Fri May 06 2011 ahmad <ahmad> 4.0.0-4.mga1
+ Revision: 95279
- Revert the deleting of .la files

* Thu May 05 2011 ahmad <ahmad> 4.0.0-3.mga1
+ Revision: 95210
- Don't ship .la files

* Sat Jan 22 2011 ahmad <ahmad> 4.0.0-2.mga1
+ Revision: 33248
- imported package getfem++


* Thu Dec 02 2010 Oden Eriksson <oeriksson@mandriva.com> 4.0.0-2mdv2011.0
+ Revision: 605447
- rebuild

* Sat Feb 13 2010 Funda Wang <fwang@mandriva.org> 4.0.0-1mdv2010.1
+ Revision: 505336
- New version 4.0.0

* Wed Apr 08 2009 Funda Wang <fwang@mandriva.org> 3.1-1mdv2009.1
+ Revision: 365112
- BR boost
- New version 3.1

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild early 2009.0 package (before pixel changes)

* Fri Apr 18 2008 Nicolas Lécureuil <nlecureuil@mandriva.com> 3.0.3-1mdv2009.0
+ Revision: 195695
- import getfem++


